# FastOpp Developer Tooling

- install uv
- install ruff, either globally with uv or locally with `uv add --dev ruff`

## New project based on FastOpp

In template_pyproject.toml, copy the relevant ruff settings into your
`pyproject.toml` file.
